@@ -1,4 +1,5 @@
 import typing
+import warnings
 from pathlib import Path
 from copy import deepcopy
 from itertools import chain
@@ -105,6 +106,10 @@ class Table:
             For more information, please check "Describing  Data" guide.
             It defaults to `['']`
 
+        on_error? (ignore|warn|raise): Define behaviour if there is an error in the
+            header or rows during the reading rows process.
+            It defaults to `ignore`.
+
         lookup? (dict): The lookup is a special object providing relational information.
             For more information, please check "Extracting  Data" guide.
 
@@ -123,11 +128,12 @@ class Table:
         encoding=None,
         compression=None,
         compression_path=None,
+        # Control/Dialect/Query/Header
         control=None,
-        # Table
         dialect=None,
         query=None,
         headers=None,
+        # Schema
         schema=None,
         sync_schema=False,
         patch_schema=False,
@@ -136,6 +142,8 @@ class Table:
         infer_volume=config.DEFAULT_INFER_VOLUME,
         infer_confidence=config.DEFAULT_INFER_CONFIDENCE,
         infer_missing_values=config.DEFAULT_MISSING_VALUES,
+        # Integrity
+        on_error="ignore",
         lookup=None,
     ):
 
@@ -177,8 +185,12 @@ class Table:
         self.__infer_volume = infer_volume
         self.__infer_confidence = infer_confidence
         self.__infer_missing_values = infer_missing_values
+        self.__on_error = on_error
         self.__lookup = lookup
 
+        # Set error handler
+        self.on_error = on_error
+
         # Create file
         self.__file = File(
             source=source,
@@ -193,6 +205,12 @@ class Table:
             query=query,
         )
 
+    def __setattr__(self, name, value):
+        if name == "on_error":
+            self.__on_error = value
+            return
+        super().__setattr__(name, value)
+
     def __enter__(self):
         if self.closed:
             self.open()
@@ -301,6 +319,24 @@ class Table:
         """
         return self.__schema
 
+    @property
+    def on_error(self):
+        """
+        Returns:
+            ignore|warn|raise: on error bahaviour
+        """
+        assert self.__on_error in ["ignore", "warn", "raise"]
+        return self.__on_error
+
+    # TODO: use property wrapper to make it shorter
+    @on_error.setter
+    def on_error(self, value):
+        """
+        Parameters:
+            value (ignore|warn|raise): on error bahaviour
+        """
+        self.__on_error = value
+
     @property
     def header(self):
         """
@@ -403,7 +439,8 @@ class Table:
         """
         return self.__parser is None
 
-    # Read
+        # Read
+        return self.__on_error
 
     def read_data(self):
         """Read data stream into memory
@@ -662,6 +699,14 @@ class Table:
     def __read_row_stream_create(self):
         schema = self.schema
 
+        # Handle header errors
+        if not self.header.valid:
+            error = self.header.errors[0]
+            if self.__on_error == "warn":
+                warnings.warn(error.message, UserWarning)
+            elif self.__on_error == "raise":
+                raise exceptions.FrictionlessException(error)
+
         # Create state
         memory_unique = {}
         memory_primary = {}
@@ -732,6 +777,14 @@ class Table:
                             error = errors.ForeignKeyError.from_row(row, note=note)
                             row.errors.append(error)
 
+            # Handle row errors
+            if not row.valid:
+                error = row.errors[0]
+                if self.__on_error == "warn":
+                    warnings.warn(error.message, UserWarning)
+                elif self.__on_error == "raise":
+                    raise exceptions.FrictionlessException(error)
+
             # Stream row
             yield row
 
